@@ -538,7 +538,12 @@ class FeatureSetCalculator(object):
         # new column names (in the child entity) for the merge
         col_map = {relationship.parent_variable.id: merge_var}
         index_as_feature = None
+
+        fillna_dict = {}
         for f in features:
+            feature_defaults = {name: f.default_value
+                                for name in f.get_feature_names() if not pd.isna(f.default_value)}
+            fillna_dict.update(feature_defaults)
             if f.base_features[0].get_name() == relationship.parent_variable.id:
                 index_as_feature = f
             base_names = f.base_features[0].get_feature_names()
@@ -565,7 +570,7 @@ class FeatureSetCalculator(object):
 
         progress_callback(len(features) / float(self.num_features))
 
-        return new_df
+        return new_df.fillna(fillna_dict)
 
     def _calculate_agg_features(self, features, frame, df_trie, progress_callback):
         test_feature = features[0]
