@@ -1,5 +1,3 @@
-import sys
-
 import pandas as pd
 import pytest
 from dask import dataframe as dd
@@ -150,8 +148,6 @@ def dd_employee_df(pd_employee_df):
 @pytest.fixture
 def ks_employee_df(pd_employee_df):
     ks = pytest.importorskip('databricks.koalas', reason="Koalas not installed, skipping")
-    if sys.platform.startswith('win'):
-        pytest.skip('skipping Koalas tests for Windows')
     return ks.from_pandas(pd_employee_df)
 
 
